/**
 * CAROL: Common Architecture for RMI Objectweb Layer
 * Copyright (C) 2009 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: InterceptionContext.java 2165 2009-05-06 07:26:22Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.carol.jndi.intercept;

import java.lang.reflect.Method;

/**
 * The Intercepted is ...
 *
 * @author Guillaume Sauthier
 */
public interface InterceptionContext {

    /**
     * Get the method being invoked.
     * @return the method (ie <code>lookup</code>, <code>bind</code>, ...)
     */
    Method getMethod();

    /**
     * Get the actual method's parameters.
     * @return the method's invocation parameters
     */
    Object[] getParameters();

    /**
     * Assign new parameters to the invocation.
     * @param parameters new set of method's parameters
     */
    void setParameters(Object[] parameters);

    /**
     * Continue the invocation flow.
     * @return the result of the next's interceptor in the chain
     * @throws Exception for any problem
     */
    Object proceed() throws Exception;
}
