/**
 * CAROL: Common Architecture for RMI Objectweb Layer
 * Copyright (C) 2009 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbstractInterceptionContext.java 2162 2009-04-29 12:13:52Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.carol.jndi.intercept.operation;

import java.util.Iterator;
import java.lang.reflect.Method;

import javax.naming.Context;

import org.ow2.carol.jndi.intercept.ContextInterceptor;
import org.ow2.carol.jndi.intercept.InterceptionContext;

/**
 * The LookupContext is ...
 *
 * @author Guillaume Sauthier
 */
public abstract class AbstractInterceptionContext implements InterceptionContext {

    private Object[] parameters;
    private Iterator<ContextInterceptor> iterator;
    private Context context;
    private Method method;

    public AbstractInterceptionContext(final Context context,
                                       final Method method) {
        this.context = context;
        this.method = method;
    }

    public Object proceed() throws Exception {
        if ((iterator != null) && (iterator.hasNext())) {
            return iterator.next().intercept(this);
        } else {
            return executeLast();
        }
    }

    protected abstract Object executeLast() throws Exception;

    public Object[] getParameters() {
        return this.parameters;
    }

    public void setParameters(final Object[] parameters) {
        this.parameters = parameters;
    }

    protected Context getContext() {
        return context;
    }

    public Method getMethod() {
        return this.method;
    }

    public void setInterceptors(final Iterator<ContextInterceptor> iterator) {
        this.iterator = iterator;
    }
}