/**
 * CAROL: Common Architecture for RMI Objectweb Layer
 * Copyright (C) 2009 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: InterceptorInitialContextFactory.java 2173 2009-06-03 14:40:03Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.carol.jndi.intercept.spi;

import java.util.Hashtable;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.naming.spi.InitialContextFactory;

import org.ow2.carol.jndi.intercept.manager.SingletonInterceptorManager;
import org.ow2.carol.jndi.spi.MultiOrbInitialContextFactory;

/**
 * The InterceptorInitialContextFactory is ...
 *
 * @author Guillaume Sauthier
 */
public class InterceptorInitialContextFactory implements InitialContextFactory {

    /**
     * Delegating InitialContextFactory to use if set.
     */
    public static final String DELEGATE_INITIAL_CONTEXT_FACTORY = "carol.interception.delegate";

    /**
     * Creates an Initial Context for beginning name resolution.
     * Special requirements of this context are supplied
     * using <code>environment</code>.
     * <p/>
     * The environment parameter is owned by the caller.
     * The implementation will not modify the object or keep a reference
     * to it, although it may keep a reference to a clone or copy.
     *
     * @param environment The possibly null environment
     *                    specifying information to be used in the creation
     *                    of the initial context.
     * @return A non-null initial context object that implements the Context
     *         interface.
     * @throws javax.naming.NamingException If cannot create an initial context.
     */
    public Context getInitialContext(final Hashtable environment) throws NamingException {
        // TODO get the wrapped Context and the singleton InterceptorManager

        Context wrapped = null;
        String delegate = System.getProperty(DELEGATE_INITIAL_CONTEXT_FACTORY);
        if (delegate != null) {
            // Use the delegate to obtain the Context
        	environment.put(Context.INITIAL_CONTEXT_FACTORY, delegate);
            wrapped = new InitialContext(environment);
        } else {
            // If no property was set, fallback on the MultiORB ICF
            InitialContextFactory factory = new MultiOrbInitialContextFactory();
            wrapped = factory.getInitialContext(environment);
        }

        return new InterceptableContext(SingletonInterceptorManager.getInterceptorManager(),
                                        wrapped);
    }
}
