/**
 * Copyright (C) 2005-2009 Bull S.A.S.
 *
 * CAROL: Common Architecture for RMI ObjectWeb Layer
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IRMIContextWrapperFactory.java 2213 2010-03-24 10:35:55Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.carol.jndi.spi;

import javax.naming.spi.InitialContextFactory;

import org.ow2.carol.jndi.ns.IRMIRegistry;
import org.ow2.carol.util.configuration.CarolDefaultValues;
import org.ow2.carol.util.configuration.ConfigurationRepository;

/**
 * Class <code> IRMIContextWrapperFactory </code> is the CAROL
 * JNDI Context factory. This context factory build the irmi context for
 * reference wrapping to/from a remote object
 * @author Guillaume Riviere
 * @author Florent Benoit (refactoring)
 * @see javax.naming.spi.InitialContextFactory
 */
public class IRMIContextWrapperFactory extends AbsInitialContextFactory implements InitialContextFactory {

    /**
     * @return class of the wrapper (to be instantiated + pool).
     */
    @Override
    protected Class<? extends IRMIContext> getWrapperClass() {
        return getWrapperClass(null);
    }
    
    /**
     * @return class of the wrapper (to be instantiated + pool).
     */
    @Override
	protected Class<? extends IRMIContext> getWrapperClass(final String url) {

    	 // use registry object when property is set to on and registry is in the same JVM.
        boolean localreg = new Boolean(System.getProperty(CarolDefaultValues.LOCALREG_JRMP_PROPERTY, "false")).booleanValue();
        if ((localreg) && IRMIRegistry.isLocal()) {
        	String protocolURL = CarolDefaultValues.CAROL_PREFIX + ".irmi." + CarolDefaultValues.URL_PREFIX;
        	String providerURL = ConfigurationRepository.getProperties().getProperty(protocolURL).toLowerCase();
        	if (providerURL.toLowerCase().equals(url.toLowerCase())) {
        		return IRMILocalContext.class;
        	}
         }
        return IRMIContext.class;   
    }

}
